@@ -4,8 +4,8 @@
 Basic integration tests for the AxiSEM database Python interface.
 
 :copyright:
-    Martin van Driel (Martin@vanDriel.de), 2014
-    Lion Krischer (krischer@geophysik.uni-muenchen.de), 2014
+    Martin van Driel (Martin@vanDriel.de), 2020
+    Lion Krischer (lion.krischer@gmail.com), 2020
 :license:
     GNU Lesser General Public License, Version 3 [non-commercial/academic use]
     (http://www.gnu.org/copyleft/lgpl.html)
